@@ -1,31 +1,59 @@
 print.gets <-
 function(x, ...)
 {
-  ##determine type:
-  spec <- switch(x$gets.type, getsm="mean", getsv="variance",
-    isat="mean")
+  ##determine spec:
+  spec <- switch(as.character(x$call)[1],
+    getsm="mean", getsv="variance")
 
-  ##header:
+  ##header - first part:
   cat("\n")
   cat("Date:", x$date, "\n")
   cat("Method: Ordinary Least Squares (OLS)\n")
+
+  ##header - if mean:
   if(spec=="mean"){
     cat("Variance-Covariance:", switch(x$aux$vcov.type,
       ordinary = "Ordinary", white = "White (1980)",
       "newey-west" = "Newey and West (1987)"), "\n")
-    cat("No. of observations (mean eq.):", x$aux$y.n, "\n")
-    cat("Sample (mean eq.):",
-      as.character(x$aux$y.index[1]), "to",
-      as.character(x$aux$y.index[x$aux$y.n]), "\n")
+    if(!is.null(x$aux$y.n)){
+      cat("No. of observations (mean eq.):", x$aux$y.n, "\n") }
   }
+
+  ##header - if variance:
   if(spec=="variance"){
-    cat("No. of observations (variance eq.):", x$aux$loge2.n, "\n")
-#needs updating!!!:
-#    cat("Sample (variance eq.):",
-#      as.character(index(na.trim(x$gum.resids.std))[1]), "to",
-#      as.character(index(na.trim(x$gum.resids.std))[length(na.trim(x$gum.resids.std))]), "\n")
+    if(!is.null(x$aux$loge2.n)){
+      cat("No. of observations (variance eq.):",
+        x$aux$loge2.n, "\n") }
+#print.arx:
+#    cat("No. of observations (variance eq.):",
+#      length(na.trim(x$resids.std)), "\n")
   }
 
+  ##header - sample info:
+  if(!is.null(x$resids)){
+    indexTrimmed <- index(na.trim(x$resids))
+    if(is.regular(x$resids)){
+      cycleTrimmed <- cycle(na.trim(x$resids))
+      startYear <- floor(as.numeric(indexTrimmed[1]))
+      startAsChar <- paste(startYear,
+        "(", cycleTrimmed[1], ")", sep="")
+      endYear <- floor(as.numeric(indexTrimmed[length(indexTrimmed)]))
+      endAsChar <- paste(endYear,
+        "(", cycleTrimmed[length(indexTrimmed)], ")", sep="")
+
+    }else{
+      startAsChar <- as.character(indexTrimmed[1])
+      endAsChar <- as.character(indexTrimmed[length(indexTrimmed)])
+    }
+    cat("Sample:", startAsChar, "to", endAsChar, "\n")
+  } #end if(!is.null..)
+
+#OLD:
+#  ##header - sample info:
+#  cat("Sample (mean eq.):",
+#    as.character(x$aux$y.index[1]), "to",
+#    as.character(x$aux$y.index[x$aux$y.n]), "\n")
+
   ##gum:
   if(spec=="mean"){
     cat("\n")
@@ -81,7 +109,7 @@ function(x, ...)
     }
 ##in the future: use estimate.specific=FALSE more directly?
     if(x$specific.spec[1]!=0 && is.null(x$mean.results)){
-      cat("Not estimated\n")
+      cat("Not estimated, since estimate.specific=FALSE\n")
     }
   }
   if(!is.null(x$variance.results)){
@@ -97,7 +125,7 @@ function(x, ...)
     print(x$specific.diagnostics)
   }
 
-  #notes:
+  ##notes:
   if(!is.null(x$notes)){
     cat("\n")
     cat("Notes:\n")
